import community
import ecm
import resolver
import keeper
import wellknown
import auth
import acl
import helpdesk
import worker
import judge
import commerce
import discussion
import asset
import content
import executor
import ranker
import course
import feed
import cognito
import geography
import l10n
import universe
import atlas
import taxonomy
import core
import apollo
import playground
import annotations



from .subscription_service_http import *
from .membership_service_http import *
from .ranking_service_http import *
from .activity_graph_service_pb2 import *
from .membership_service_pb2 import *
from .group_service_pb2 import *
from .activity_graph_service_http import *
from .account_service_http import *
from .tier_pb2 import *
from .configuration_service_http import *
from .member_user_pb2 import *
from .subscription_service_pb2 import *
from .member_team_pb2 import *
from .account_service_pb2 import *
from .ranking_point_pb2 import *
from .linked_account_service_http import *
from .member_service_http import *
from .configuration_service_pb2 import *
from .member_pb2 import *
from .configuration_identity_pb2 import *
from .tier_service_pb2 import *
from .ranking_service_pb2 import *
from .group_pb2 import *
from .attribute_service_http import *
from .ranking_event_pb2 import *
from .member_service_pb2 import *
from .tier_service_http import *
from .attribute_service_pb2 import *
from .member_ghost_pb2 import *
from .linked_account_service_pb2 import *
from .events_pb2 import *
from .configuration_idp_pb2 import *
from .attribute_pb2 import *
from .subscription_pb2 import *
from .linked_account_pb2 import *
from .group_service_http import *



import os
import sys
import setuptools

# create __init__ in each namespace and export everything
source = "." + os.sep + "eolymp"
root_init = source + os.sep + "__init__.py"

print("creating", root_init, "file")
with open(root_init, "w", encoding="utf-8") as ri:
    for module in os.listdir(source):
        module_path = source + os.sep + module
        if not os.path.isdir(module_path):
            continue

        ri.write("import {}\n".format(module))

        module_init = module_path + os.sep + "__init__.py"

        print("creating", module_init, "file")
        with open(module_init, "w", encoding="utf-8") as mi:
            for file in os.listdir(module_path):
                name = os.path.splitext(file)
                ext = name[1] if len(name) > 1 else ''

                if os.path.isdir(module_path + os.sep + file) or ext != '.py' or name[0] == '__init__':
                    continue

                mi.write("from .{} import *\n".format(name[0]))


with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="eolymp",
    version=os.getenv("RELEASE_VERSION"),
    author="Sergey Kolodyazhnyy",
    author_email="sergey@eolymp.com",
    description="Eolymp SDK for Python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/eolymp/contracts",
    packages=setuptools.find_packages(),
    package_data={package: ["py.typed", "*.pyi", "**/*.pyi"] for package in setuptools.find_packages()},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.0',
)
